# EConflux

A library for binning, geolocation, processing, and statistical analysis of multi-method geophysical data.

EConflux is designed to support users conducting joint geophysical investigations by providing functions to assist with georeferencing, co-locating, processing, and interpreting complementary geophysical datasets.

The current version of EConflux is designed to be incorporated into workflows using ResIPy (https://gitlab.com/hkex/resipy) and EMagPy (https://gitlab.com/hkex/emagpy) but should provide a suitable foundation for users looking to incorporate the functions into other inversion codes.

## Installing EConflux

Currently, it is recommended to install EConflux by cloning the repository and adding the path to the "code" folder to your system paths.


Navigate to a preferred directory:
```
cd Documents
```
```
git clone https://github.com/c-terra/EConflux
```
See the Jupyter Notebooks in the "examples" folder to see how the EConflux classes are called.

NOTE: The Jupyter Notebooks in the "examples" folder might require additional packages not included in requirements.txt

## Overview of EConflux Classes and Structure


<img width="2411" height="1586" alt="image" src="https://github.com/user-attachments/assets/f195a182-4f42-4c46-a9ef-222875a13089" />
